==> yuebing-1.3.26.tgz: package/serverMiddleware/api/user/authenticate.js <==
const api = require('../../util/api')
const u = require('../../user/userUtil')
const system = require('../../util/config').SYSTEM
const logger = system.logger

const ACCOUNT_NOT_FOUND = { email: ['accountNotFound'] }

export default {
  path: '/api/user/authenticate',
  handler (req, res) {
    logger.info(`>>>>> API: Authenticate ${req.url} ....`)
    req.on('data', (data) => {
      const loginRequest = JSON.parse(data.toString())
      if (typeof loginRequest.usernameOrEmail === 'string' && loginRequest.usernameOrEmail.length > 1) {
        u.findUser(loginRequest.usernameOrEmail).then(
          (user) => {
            if (!user) {
              logger.info(`>>>>> API: Authenticate: user not found: ${loginRequest.usernameOrEmail}`)
              return api.validationFailed(res, ACCOUNT_NOT_FOUND)
            }
            u.checkPassword(user, loginRequest.password, (ok) => {
              if (ok) {
                u.startSession(user).then(
                  (sessionUser) => {
                    if (u.isAdmin(sessionUser)) {
                      sessionUser.admin = true
                    }
                    api.setSessionCookie(res, sessionUser.session)
                    api.okJson(res, sessionUser)
                  },
                  (error) => {
                    logger.error(`>>>>> API: Authenticate: error starting session: ${error}`)
                    api.serverError(res, `Error: ${error}`)
                  })
              } else {
                logger.info(`>>>>> API: Authenticate: wrong password (ok was ${ok})`)
                return api.validationFailed(res, ACCOUNT_NOT_FOUND)
              }
            },
            (err) => {
              logger.info(`>>>>> API: Authenticate: error (err was ${err})`)
              return api.validationFailed(res, ACCOUNT_NOT_FOUND)
            })
          },
          (err) => {
            logger.error(`>>>>> API: Authenticate: error reading user record: ${JSON.stringify(err)}`)
            return api.validationFailed(res, ACCOUNT_NOT_FOUND)
          }
        )
      }
    })
  }
}

==> yuebing-1.4.3.tgz: package/serverMiddleware/api/user/authenticate.js <==
import bcrypt from 'bcryptjs'

const api = require('../../util/api')
const u = require('../../user/userUtil')
const system = require('../../util/config').SYSTEM
const logger = system.logger

const ACCOUNT_NOT_FOUND = { email: ['accountNotFound'] }

export default {
  path: '/api/user/authenticate',
  handler (req, res) {
    logger.info(`>>>>> API: Authenticate ${req.url} ....`)
    req.on('data', (data) => {
      const loginRequest = JSON.parse(data.toString())
      if (system.allowLocalAdmin()) {
        u.startSession(u.LOCAL_ADMIN_USER).then(
          (sessionUser) => {
            sessionUser.admin = true
            api.setSessionCookie(res, sessionUser.session)
            api.okJson(res, sessionUser)
          },
          (error) => {
            logger.error(`>>>>> API: Authenticate: error starting local/admin session: ${error}`)
            api.serverError(res, `Error: ${error}`)
          })
      } else if (typeof loginRequest.usernameOrEmail === 'string' && loginRequest.usernameOrEmail.length > 1) {
        u.findUser(loginRequest.usernameOrEmail).then(
          (user) => {
            if (!user) {
              logger.info(`>>>>> API: Authenticate: user not found: ${loginRequest.usernameOrEmail}`)
              return api.validationFailed(res, ACCOUNT_NOT_FOUND)
            }
            u.checkPassword(user, loginRequest.password, (ok) => {
              if (ok) {
                u.startSession(user).then(
                  (sessionUser) => {
                    if (u.isAdmin(sessionUser)) {
                      sessionUser.admin = true
                    }
                    api.setSessionCookie(res, sessionUser.session)
                    api.okJson(res, sessionUser)
                  },
                  (error) => {
                    logger.error(`>>>>> API: Authenticate: error starting session: ${error}`)
                    api.serverError(res, `Error: ${error}`)
                  })
              } else {
                logger.info(`>>>>> API: Authenticate: wrong password (ok was ${ok})`)
                return api.validationFailed(res, ACCOUNT_NOT_FOUND)
              }
            },
            (err) => {
              logger.info(`>>>>> API: Authenticate: error (err was ${err})`)
              return api.validationFailed(res, ACCOUNT_NOT_FOUND)
            })
          },
          (err) => {
            logger.error(`>>>>> API: Authenticate: error reading user record: ${JSON.stringify(err)}`)
            return api.validationFailed(res, ACCOUNT_NOT_FOUND)
          }
        )
      }
    })
  }
}
